##  Frequency of Updates
Most of the metrics in each section are refreshed daily around 6:00AM UTC. Exceptions are:
  * Academy Activity: refreshed monthly around the 5th working day of the month
  * Product Ideas: refreshed on a bi-weekly basis
